@@ -1,11 +1,10 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2002-2006 Peter Miller;
-//	All rights reserved.
+//	Copyright (C) 2002-2008 Peter Miller
 //
 //	This program is free software; you can redistribute it and/or modify
 //	it under the terms of the GNU General Public License as published by
-//	the Free Software Foundation; either version 2 of the License, or
+//	the Free Software Foundation; either version 3 of the License, or
 //	(at your option) any later version.
 //
 //	This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
 //	GNU General Public License for more details.
 //
 //	You should have received a copy of the GNU General Public License
-//	along with this program; if not, write to the Free Software
-//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: functions to manipulate aecps
+//	along with this program. If not, see
+//	<http://www.gnu.org/licenses/>.
 //
 
 #include <libaegis/arglex2.h>
@@ -38,7 +35,7 @@
 
 
 static void
-destructor(command_ty *this_thing)
+destructor(command_ty *)
 {
 }
 
@@ -50,7 +47,7 @@ do_nothing(void)
 
 
 static complete_ty *
-completion_get(command_ty *cmd)
+completion_get(command_ty *)
 {
     string_ty       *project_name;
     int             overwriting;
@@ -62,8 +59,8 @@ completion_get(command_ty *cmd)
     int             change_number;
     const char      *branch;
     project_ty      *pp;
-    user_ty         *up;
-    change_ty       *cp;
+    user_ty::pointer up;
+    change::pointer cp;
     int             independent;
 
     arglex2_retable(0);
@@ -232,7 +229,7 @@ completion_get(command_ty *cmd)
 
 	case arglex_token_base_relative:
 	case arglex_token_current_relative:
-	    user_relative_filename_preference_argument(do_nothing);
+	    user_ty::relative_filename_preference_argument(do_nothing);
 	    break;
 	}
 	arglex();
@@ -242,7 +239,10 @@ completion_get(command_ty *cmd)
     // Work out which project to use.
     //
     if (!project_name)
-	project_name = user_default_project();
+    {
+        nstring n = user_ty::create()->default_project();
+	project_name = str_copy(n.get_ref());
+    }
     pp = project_alloc(project_name);
     pp->bind_existing();
 
@@ -281,7 +281,7 @@ completion_get(command_ty *cmd)
     //
     // locate user data
     //
-    up = user_executing(pp);
+    up = user_ty::create();
 
     //
     // locate change data
@@ -298,7 +298,7 @@ completion_get(command_ty *cmd)
     else
     {
 	if (!change_number)
-	    change_number = user_default_change(up);
+	    change_number = up->default_change(pp);
 	cp = change_alloc(pp, change_number);
 	change_bind_existing(cp);
     }
@@ -312,9 +312,8 @@ completion_get(command_ty *cmd)
 	    independent
 	||
 	    (
-		user_relative_filename_preference
+		up->relative_filename_preference
 		(
-		    up,
 		    uconf_relative_filename_preference_current
 		)
 	    ==
