@@ -1,11 +1,10 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2003, 2005, 2006 Peter Miller;
-//	All rights reserved.
+//	Copyright (C) 2003, 2005-2008 Peter Miller
 //
 //	This program is free software; you can redistribute it and/or modify
 //	it under the terms of the GNU General Public License as published by
-//	the Free Software Foundation; either version 2 of the License, or
+//	the Free Software Foundation; either version 3 of the License, or
 //	(at your option) any later version.
 //
 //	This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
 //	GNU General Public License for more details.
 //
 //	You should have received a copy of the GNU General Public License
-//	along with this program; if not, write to the Free Software
-//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: interface definition for aeget/get/change/aetar.c
+//	along with this program. If not, see
+//	<http://www.gnu.org/licenses/>.
 //
 
 #ifndef AEGET_GET_CHANGE_AETAR_H
@@ -25,11 +22,10 @@
 
 #include <common/main.h>
 
-struct change_ty; // forward
 struct string_ty; // forward
 struct string_list_ty; // forward
 
-void get_change_aetar(struct change_ty *, struct string_ty *,
+void get_change_aetar(change::pointer , struct string_ty *,
     struct string_list_ty *);
 
 #endif // AEGET_GET_CHANGE_AETAR_H
