@@ -1,11 +1,10 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1991-1993, 1998, 2002, 2005, 2006 Peter Miller;
-//	All rights reserved.
+//	Copyright (C) 1991-1993, 1998, 2002, 2005-2008 Peter Miller
 //
 //	This program is free software; you can redistribute it and/or modify
 //	it under the terms of the GNU General Public License as published by
-//	the Free Software Foundation; either version 2 of the License, or
+//	the Free Software Foundation; either version 3 of the License, or
 //	(at your option) any later version.
 //
 //	This program is distributed in the hope that it will be useful,
@@ -14,21 +13,20 @@
 //	GNU General Public License for more details.
 //
 //	You should have received a copy of the GNU General Public License
-//	along with this program; if not, write to the Free Software
-//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: interface definition for aegis/aenc.c
+//	along with this program. If not, see
+//	<http://www.gnu.org/licenses/>.
 //
 
 #ifndef AEGIS_AENC_H
 #define AEGIS_AENC_H
 
 #include <common/main.h>
+#include <libaegis/user.h>
 
 void new_change(void);
 
 struct project_ty; // existence
-struct user_ty; // existence
-void new_change_check_permission(struct project_ty *, struct user_ty *);
+
+void new_change_check_permission(project_ty *pp, user_ty::pointer up);
 
 #endif // AEGIS_AENC_H
