@@ -1,11 +1,10 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1991-1995, 1997-1999, 2001-2006 Peter Miller;
-//	All rights reserved.
+//	Copyright (C) 1991-1995, 1997-1999, 2001-2008 Peter Miller
 //
 //	This program is free software; you can redistribute it and/or modify
 //	it under the terms of the GNU General Public License as published by
-//	the Free Software Foundation; either version 2 of the License, or
+//	the Free Software Foundation; either version 3 of the License, or
 //	(at your option) any later version.
 //
 //	This program is distributed in the hope that it will be useful,
@@ -14,31 +13,31 @@
 //	GNU General Public License for more details.
 //
 //	You should have received a copy of the GNU General Public License
-//	along with this program; if not, write to the Free Software
-//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: functions to implement new developer
+//	along with this program. If not, see
+//	<http://www.gnu.org/licenses/>.
 //
 
 #include <common/ac/stdio.h>
 #include <common/ac/stdlib.h>
 
+#include <common/progname.h>
+#include <common/quit.h>
+#include <common/str_list.h>
+#include <common/trace.h>
 #include <libaegis/ael/project/developers.h>
-#include <aegis/aend.h>
-#include <libaegis/arglex2.h>
 #include <libaegis/arglex/project.h>
+#include <libaegis/arglex2.h>
+#include <libaegis/change/identifier.h>
 #include <libaegis/commit.h>
 #include <libaegis/help.h>
 #include <libaegis/lock.h>
 #include <libaegis/os.h>
-#include <common/progname.h>
 #include <libaegis/project.h>
 #include <libaegis/project/history.h>
-#include <common/quit.h>
 #include <libaegis/sub.h>
-#include <common/trace.h>
 #include <libaegis/user.h>
-#include <common/str_list.h>
+
+#include <aegis/aend.h>
 
 
 static void
@@ -74,30 +73,11 @@ new_developer_help(void)
 static void
 new_developer_list(void)
 {
-    string_ty	    *project_name;
-
     trace(("new_developer_list()\n{\n"));
     arglex();
-    project_name = 0;
-    while (arglex_token != arglex_token_eoln)
-    {
-	switch (arglex_token)
-	{
-	default:
-	    generic_argument(new_developer_usage);
-	    continue;
-
-	case arglex_token_project:
-	    arglex();
-	    // fall through...
-
-	case arglex_token_string:
-	    arglex_parse_project(&project_name, new_developer_usage);
-	    continue;
-	}
-	arglex();
-    }
-    list_developers(project_name, 0, 0);
+    change_identifier cid;
+    cid.command_line_parse_rest(new_developer_usage);
+    list_developers(cid, 0);
     trace(("}\n"));
 }
 
@@ -106,12 +86,12 @@ static void
 new_developer_inner(project_ty *pp, string_list_ty *wlp, int strict)
 {
     size_t          j;
-    user_ty	    *up;
+    user_ty::pointer up;
 
     //
     // locate user data
     //
-    up = user_executing(pp);
+    up = user_ty::create();
 
     //
     // lock the project for change
@@ -122,7 +102,7 @@ new_developer_inner(project_ty *pp, string_list_ty *wlp, int strict)
     //
     // check they are allowed to do this
     //
-    if (!project_administrator_query(pp, user_name(up)))
+    if (!project_administrator_query(pp, up->name()))
 	project_fatal(pp, 0, i18n("not an administrator"));
 
     //
@@ -130,26 +110,20 @@ new_developer_inner(project_ty *pp, string_list_ty *wlp, int strict)
     //
     for (j = 0; j < wlp->nstrings; ++j)
     {
-	user_ty		*candidate;
+	user_ty::pointer candidate;
 
 	//
 	// make sure the user isn't already there
 	//
-	candidate = user_symbolic(pp, wlp->string[j]);
-	if (project_developer_query(pp, user_name(candidate)))
+	candidate = user_ty::create(nstring(wlp->string[j]));
+	if (project_developer_query(pp, candidate->name()))
 	{
-	    sub_context_ty  *scp;
-
 	    if (!strict)
-	    {
-		user_free(candidate);
 		continue;
-	    }
-	    scp = sub_context_new();
-	    sub_var_set_string(scp, "Name", user_name(candidate));
-	    project_fatal(pp, scp, i18n("$name already developer"));
+	    sub_context_ty sc;
+	    sc.var_set_string("Name", candidate->name());
+	    project_fatal(pp, &sc, i18n("$name already developer"));
 	    // NOTREACHED
-	    sub_context_delete(scp);
 	}
 
 	//
@@ -157,14 +131,13 @@ new_developer_inner(project_ty *pp, string_list_ty *wlp, int strict)
 	//	(should we chech s/he is in the project's group?)
 	// this is to avoid security holes
 	//
-	if (!user_uid_check(user_name(candidate)))
-	    fatal_user_too_privileged(user_name(candidate));
+	if (!candidate->check_uid())
+	    fatal_user_too_privileged(candidate->name());
 
 	//
 	// add it to the list
 	//
-	project_developer_add(pp, user_name(candidate));
-	user_free(candidate);
+	project_developer_add(pp, candidate->name());
     }
 
     //
@@ -174,8 +147,6 @@ new_developer_inner(project_ty *pp, string_list_ty *wlp, int strict)
     commit();
     lock_release();
 
-    user_free(up);
-
     //
     // verbose success message
     //
@@ -245,7 +216,7 @@ new_developer_main(void)
 
 	case arglex_token_wait:
 	case arglex_token_wait_not:
-	    user_lock_wait_argument(new_developer_usage);
+	    user_ty::lock_wait_argument(new_developer_usage);
 	    break;
 	}
 	arglex();
@@ -260,7 +231,10 @@ new_developer_main(void)
     // locate project data
     //
     if (!project_name)
-	project_name = user_default_project();
+    {
+        nstring n = user_ty::create()->default_project();
+	project_name = str_copy(n.get_ref());
+    }
     pp = project_alloc(project_name);
     str_free(project_name);
     pp->bind_existing();
@@ -293,8 +267,8 @@ new_developer(void)
 {
     static arglex_dispatch_ty dispatch[] =
     {
-	{arglex_token_help, new_developer_help, },
-	{arglex_token_list, new_developer_list, },
+	{ arglex_token_help, new_developer_help, 0 },
+	{ arglex_token_list, new_developer_list, 0 },
     };
 
     trace(("new_developer()\n{\n"));
