@@ -1,11 +1,10 @@
 //
 //      aegis - project change supervisor
-//      Copyright (C) 2001, 2002, 2004, 2005 Peter Miller;
-//      All rights reserved.
+//      Copyright (C) 2001, 2002, 2004-2006, 2008 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
-//      the Free Software Foundation; either version 2 of the License, or
+//      the Free Software Foundation; either version 3 of the License, or
 //      (at your option) any later version.
 //
 //      This program is distributed in the hope that it will be useful,
@@ -14,14 +13,11 @@
 //      GNU General Public License for more details.
 //
 //      You should have received a copy of the GNU General Public License
-//      along with this program; if not, write to the Free Software
-//      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: functions to manipulate search_lists
+//      along with this program. If not, see
+//      <http://www.gnu.org/licenses/>.
 //
 
 #include <aeimport/format/search_list.h>
-#include <common/mem.h>
 #include <common/str_list.h>
 
 
@@ -30,7 +26,7 @@ format_search_list_new(void)
 {
     format_search_list_ty *fslp;
 
-    fslp = (format_search_list_ty *)mem_alloc(sizeof(format_search_list_ty));
+    fslp = new format_search_list_ty;
     fslp->item = 0;
     fslp->length = 0;
     fslp->maximum = 0;
@@ -45,12 +41,11 @@ format_search_list_delete(format_search_list_ty *fslp)
 
     for (j = 0; j < fslp->length; ++j)
         format_search_delete(fslp->item[j]);
-    if (fslp->item)
-        mem_free(fslp->item);
+    delete [] fslp->item;
     fslp->item = 0;
     fslp->length = 0;
     fslp->maximum = 0;
-    mem_free(fslp);
+    delete fslp;
 }
 
 
@@ -59,11 +54,12 @@ format_search_list_append(format_search_list_ty *fslp, format_search_ty *fsp)
 {
     if (fslp->length >= fslp->maximum)
     {
-        size_t          nbytes;
-
         fslp->maximum = fslp->maximum * 2 + 8;
-        nbytes = fslp->maximum * sizeof(fslp->item[0]);
-        fslp->item = (format_search_ty **)mem_change_size(fslp->item, nbytes);
+	format_search_ty **new_item = new format_search_ty * [fslp->maximum];
+	for (size_t j = 0; j < fslp->length; ++j)
+	    new_item[j] = fslp->item[j];
+	delete [] fslp->item;
+	fslp->item = new_item;
     }
     fslp->item[fslp->length++] = fsp;
 }
