@@ -1,11 +1,10 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004, 2005 Peter Miller;
-//	All rights reserved.
+//	Copyright (C) 2004-2008 Peter Miller
 //
 //	This program is free software; you can redistribute it and/or modify
 //	it under the terms of the GNU General Public License as published by
-//	the Free Software Foundation; either version 2 of the License, or
+//	the Free Software Foundation; either version 3 of the License, or
 //	(at your option) any later version.
 //
 //	This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
 //	GNU General Public License for more details.
 //
 //	You should have received a copy of the GNU General Public License
-//	along with this program; if not, write to the Free Software
-//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: program to generate the Makefile.in file
+//	along with this program. If not, see
+//	<http://www.gnu.org/licenses/>.
 //
 // This was originally a shell script, but as the number of files grew,
 // its execution time became unreasonably slow.
@@ -31,6 +28,7 @@
 #include <common/error.h>
 #include <common/language.h>
 #include <common/nstring/list.h>
+#include <common/rsrc_limits.h>
 #include <aemakefile/printer/stdout.h>
 #include <aemakefile/printer/wrap.h>
 #include <aemakefile/process/body.h>
@@ -98,6 +96,7 @@ main(int argc, char **argv)
     arglex_init(argc, argv, argtab);
     env_initialize();
     language_init();
+    resource_limits_init();
 
     if (arglex() == arglex_token_help)
 	usage();
