@@ -1,11 +1,10 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2001, 2003-2005 Peter Miller;
-//	All rights reserved.
+//	Copyright (C) 2001, 2003-2008 Peter Miller
 //
 //	This program is free software; you can redistribute it and/or modify
 //	it under the terms of the GNU General Public License as published by
-//	the Free Software Foundation; either version 2 of the License, or
+//	the Free Software Foundation; either version 3 of the License, or
 //	(at your option) any later version.
 //
 //	This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
 //	GNU General Public License for more details.
 //
 //	You should have received a copy of the GNU General Public License
-//	along with this program; if not, write to the Free Software
-//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: functions to manipulate nextchannumbs
+//	along with this program. If not, see
+//	<http://www.gnu.org/licenses/>.
 //
 
 #include <libaegis/change/branch.h>
@@ -28,21 +25,18 @@
 
 
 long
-change_branch_next_change_number(change_ty *cp, int is_a_change)
+change_branch_next_change_number(change::pointer cp, int is_a_change)
 {
     cstate_ty       *cstate_data;
     cstate_branch_change_list_ty *lp;
     long            change_number;
-    interval_ty     *ip1;
-    interval_ty     *ip2;
-    interval_ty     *ip3;
     size_t          j, k;
-    long            min;
+    long            minchanum;
     int             reuse;
 
     trace(("change_branch_next_change_number(cp = %8.8lX)\n{\n",
 	(long)cp));
-    cstate_data = change_cstate_get(cp);
+    cstate_data = cp->cstate_get();
     assert(cstate_data->branch);
     if (!cstate_data->branch->change)
     {
@@ -56,34 +50,28 @@ change_branch_next_change_number(change_ty *cp, int is_a_change)
     // build an interval which contains the set of changes
     // (it could be empty)
     //
-    ip1 = interval_create_empty();
+    interval ip1;
     for (j = 0; j < lp->length; )
     {
 	for (k = j + 1; k < lp->length; ++k)
 	    if (lp->list[k - 1] + 1 != lp->list[k])
 	       	break;
-	ip2 = interval_create_range(lp->list[j], lp->list[k - 1]);
-	ip3 = interval_union(ip1, ip2);
-	interval_free(ip1);
-	interval_free(ip2);
-	ip1 = ip3;
+	ip1 += interval(lp->list[j], lp->list[k - 1]);
 	j = k;
     }
 
     //
-    // difference the above set from the interval [min..max)
+    // difference the above set from the interval [minchanum..max)
     // This avoids zero.  If the user wants a zero-numbered change,
     // she must ask for it.
     //
     if (is_a_change)
-	min = change_branch_minimum_change_number_get(cp);
+	minchanum = change_branch_minimum_change_number_get(cp);
     else
-	min = change_branch_minimum_branch_number_get(cp);
-    ip2 = interval_create_range(min, TRUNK_CHANGE_NUMBER - 1);
-    ip3 = interval_difference(ip2, ip1);
-    interval_free(ip1);
-    interval_free(ip2);
-    assert(ip3->length);
+	minchanum = change_branch_minimum_branch_number_get(cp);
+    interval ip2(minchanum, TRUNK_CHANGE_NUMBER - 1);
+    interval ip3 = ip2 - ip1;
+    assert(!ip3.empty());
 
     //
     // The result is the minimum acceptable number in the interval.
@@ -93,29 +81,24 @@ change_branch_next_change_number(change_ty *cp, int is_a_change)
     if (!change_branch_skip_unlucky_get(cp))
     {
 	if (reuse)
-    	    change_number = ip3->data[0];
+    	    change_number = ip3.first();
 	else
-    	    change_number = ip3->data[ip3->length - 2];
+    	    change_number = ip3.second_last();
     }
     else
     {
 	for (;;)
 	{
 	    if (reuse)
-		change_number = ip3->data[0];
+		change_number = ip3.first();
 	    else
-		change_number = ip3->data[ip3->length - 2];
-	    min = skip_unlucky(change_number);
-	    if (min == change_number)
+		change_number = ip3.second_last();
+	    minchanum = skip_unlucky(change_number);
+	    if (minchanum == change_number)
 		break;
-	    ip1 = interval_create_range(change_number, min - 1);
-	    ip2 = interval_difference(ip3, ip1);
-	    interval_free(ip3);
-	    interval_free(ip1);
-	    ip3 = ip2;
+	    ip3 -= interval(change_number, minchanum - 1);
 	}
     }
-    interval_free(ip3);
     trace(("return %ld;\n", change_number));
     trace(("}\n"));
     return change_number;
