@@ -1,11 +1,10 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2002-2005 Peter Miller;
-//	All rights reserved.
+//	Copyright (C) 2002-2008 Peter Miller
 //
 //	This program is free software; you can redistribute it and/or modify
 //	it under the terms of the GNU General Public License as published by
-//	the Free Software Foundation; either version 2 of the License, or
+//	the Free Software Foundation; either version 3 of the License, or
 //	(at your option) any later version.
 //
 //	This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
 //	GNU General Public License for more details.
 //
 //	You should have received a copy of the GNU General Public License
-//	along with this program; if not, write to the Free Software
-//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: functions to manipulate bys
+//	along with this program. If not, see
+//	<http://www.gnu.org/licenses/>.
 //
 
 #include <libaegis/change/branch.h>
@@ -26,7 +23,8 @@
 
 
 long
-change_history_change_by_name(change_ty *cp, string_ty *delta_name, int errok)
+change_history_change_by_name(change::pointer cp, string_ty *delta_name,
+    int errok)
 {
     cstate_ty       *cstate_data;
     cstate_branch_history_list_ty *h;
@@ -34,7 +32,7 @@ change_history_change_by_name(change_ty *cp, string_ty *delta_name, int errok)
     string_ty       *best;
     double          best_weight;
 
-    cstate_data = change_cstate_get(cp);
+    cstate_data = cp->cstate_get();
     if (!cstate_data->branch)
 	goto useless;
     h = cstate_data->branch->history;
