@@ -1,11 +1,10 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2004, 2005 Peter Miller;
-//	All rights reserved.
+//	Copyright (C) 2004-2008 Peter Miller
 //
 //	This program is free software; you can redistribute it and/or modify
 //	it under the terms of the GNU General Public License as published by
-//	the Free Software Foundation; either version 2 of the License, or
+//	the Free Software Foundation; either version 3 of the License, or
 //	(at your option) any later version.
 //
 //	This program is distributed in the hope that it will be useful,
@@ -14,16 +13,15 @@
 //	GNU General Public License for more details.
 //
 //	You should have received a copy of the GNU General Public License
-//	along with this program; if not, write to the Free Software
-//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: implementation of the collect class
+//	along with this program. If not, see
+//	<http://www.gnu.org/licenses/>.
 //
 
 #include <common/ac/string.h>
 
+#include <common/mem.h>
+#include <common/wstring.h>
 #include <libaegis/collect.h>
-#include <common/wstr.h>
 
 
 collect::~collect()
@@ -89,10 +87,17 @@ collect::append(const wchar_t *s, size_t n)
 }
 
 
-wstring_ty *
+void
+collect::push_back(const wstring &s)
+{
+    append(s.c_str(), s.size());
+}
+
+
+wstring
 collect::end()
 {
-    wstring_ty *result = wstr_n_from_wc(buf, pos);
+    wstring result(buf, pos);
     pos = 0;
     return result;
 }
