@@ -1,11 +1,10 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1991-1995, 1998, 1999, 2001-2006 Peter Miller;
-//	All rights reserved.
+//	Copyright (C) 1991-1995, 1998, 1999, 2001-2008 Peter Miller
 //
 //	This program is free software; you can redistribute it and/or modify
 //	it under the terms of the GNU General Public License as published by
-//	the Free Software Foundation; either version 2 of the License, or
+//	the Free Software Foundation; either version 3 of the License, or
 //	(at your option) any later version.
 //
 //	This program is distributed in the hope that it will be useful,
@@ -14,10 +13,8 @@
 //	GNU General Public License for more details.
 //
 //	You should have received a copy of the GNU General Public License
-//	along with this program; if not, write to the Free Software
-//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: functions to parse aegis' data files
+//	along with this program. If not, see
+//	<http://www.gnu.org/licenses/>.
 //
 
 #include <common/ac/time.h>
@@ -35,7 +32,7 @@ static sem_ty	*sem_root;
 
 
 void *
-parse(string_ty *filename, type_ty *type)
+parse(string_ty *filename, meta_type *type)
 {
     void	    *addr;
 
@@ -62,7 +59,7 @@ parse(string_ty *filename, type_ty *type)
 
 
 void *
-parse_env(const char *name, type_ty *type)
+parse_env(const char *name, meta_type *type)
 {
     void	    *addr;
 
@@ -88,7 +85,7 @@ parse_env(const char *name, type_ty *type)
 
 
 void *
-parse_input(input &ifp, type_ty *type)
+parse_input(input &ifp, meta_type *type)
 {
     trace(("parse_input(ifp = *%08lX, type = %08lx)\n{\n", (long)&ifp,
 	(long)type));
@@ -113,7 +110,7 @@ parse_input(input &ifp, type_ty *type)
 
 
 void
-sem_push(type_ty *type, void *addr)
+sem_push(meta_type *type, void *addr)
 {
     sem_ty	    *sp;
 
@@ -305,7 +302,7 @@ sem_list(void)
     }
     else
     {
-	type_ty		*type;
+	meta_type		*type;
 	void		*addr;
 
 	addr = sem_root->type->list_parse(sem_root->addr, &type);
@@ -318,7 +315,7 @@ sem_list(void)
 	    void	    *contents;
 
 	    contents = type->alloc();
-	    *(generic_struct_ty **)addr = (generic_struct_ty *)contents;
+	    *(generic_struct **)addr = (generic_struct *)contents;
 	    addr = contents;
 	}
 
@@ -350,13 +347,13 @@ sem_field(string_ty *name)
     }
     else
     {
-	type_ty		*type;
+	meta_type		*type;
 	void		*addr;
 	unsigned long	mask;
-	generic_struct_ty *gsp;
+	generic_struct *gsp;
 	int             redefok;
 
-	gsp = (generic_struct_ty *)sem_root->addr;
+	gsp = (generic_struct *)sem_root->addr;
 	redefok = 0;
 	addr = sem_root->type->struct_parse(gsp, name, &type, &mask, &redefok);
 	if (!addr)
@@ -408,7 +405,7 @@ sem_field(string_ty *name)
 		    gsp->mask |= mask;
 		    trace(("gsp->mask == 0x%08lX;\n", gsp->mask));
 		    if (type->alloc)
-			addr = (void *)*(generic_struct_ty **)addr;
+			addr = (void *)*(generic_struct **)addr;
 		    sem_push(type, addr);
 		    trace(("}\n"));
 		    return;
@@ -430,7 +427,7 @@ sem_field(string_ty *name)
 		void		*contents;
 
 		contents = type->alloc();
-		*(generic_struct_ty **)addr = (generic_struct_ty *)contents;
+		*(generic_struct **)addr = (generic_struct *)contents;
 		addr = contents;
 	    }
 
