@@ -1,11 +1,10 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1999, 2002, 2005, 2006 Peter Miller;
-//	All rights reserved.
+//	Copyright (C) 1999, 2002, 2005-2008 Peter Miller
 //
 //	This program is free software; you can redistribute it and/or modify
 //	it under the terms of the GNU General Public License as published by
-//	the Free Software Foundation; either version 2 of the License, or
+//	the Free Software Foundation; either version 3 of the License, or
 //	(at your option) any later version.
 //
 //	This program is distributed in the hope that it will be useful,
@@ -14,21 +13,17 @@
 //	GNU General Public License for more details.
 //
 //	You should have received a copy of the GNU General Public License
-//	along with this program; if not, write to the Free Software
-//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: interface definition for libaegis/sub/capitalize.c
+//	along with this program. If not, see
+//	<http://www.gnu.org/licenses/>.
 //
 
 #ifndef LIBAEGIS_SUB_CAPITALIZE_H
 #define LIBAEGIS_SUB_CAPITALIZE_H
 
-#include <common/main.h>
+class sub_context_ty; // forward
+class wstring; // forward
+class wstring_list; // forward
 
-struct sub_context_ty; // existence
-struct wstring_list_ty; // existence
-
-struct wstring_ty *sub_capitalize(struct sub_context_ty *,
-	struct wstring_list_ty *arg);
+wstring sub_capitalize(sub_context_ty *, const wstring_list &);
 
 #endif // LIBAEGIS_SUB_CAPITALIZE_H
