@@ -1,11 +1,10 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2001-2006 Peter Miller;
-//	All rights reserved.
+//	Copyright (C) 2001-2008 Peter Miller
 //
 //	This program is free software; you can redistribute it and/or modify
 //	it under the terms of the GNU General Public License as published by
-//	the Free Software Foundation; either version 2 of the License, or
+//	the Free Software Foundation; either version 3 of the License, or
 //	(at your option) any later version.
 //
 //	This program is distributed in the hope that it will be useful,
@@ -14,17 +13,15 @@
 //	GNU General Public License for more details.
 //
 //	You should have received a copy of the GNU General Public License
-//	along with this program; if not, write to the Free Software
-//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: functions to manipulate histo_direcs
+//	along with this program. If not, see
+//	<http://www.gnu.org/licenses/>.
 //
 
 #include <libaegis/project.h>
 #include <libaegis/sub.h>
 #include <libaegis/sub/histo_direc.h>
 #include <common/trace.h>
-#include <common/wstr/list.h>
+#include <common/wstring/list.h>
 
 
 //
@@ -48,31 +45,28 @@
 //	or NULL on error, setting suberr appropriately.
 //
 
-wstring_ty *
-sub_history_directory(sub_context_ty *scp, wstring_list_ty *arg)
+wstring
+sub_history_directory(sub_context_ty *scp, const wstring_list &arg)
 {
-    wstring_ty	    *result;
-    project_ty	    *pp;
-
     trace(("sub_history_directory()\n{\n"));
-    if (arg->size() != 1)
+    wstring result;
+    if (arg.size() != 1)
     {
-	sub_context_error_set(scp, i18n("requires zero arguments"));
-	result = 0;
-	goto done;
+	scp->error_set(i18n("requires zero arguments"));
+        trace(("}\n"));
+        return result;
     }
-    pp = sub_context_project_get(scp);
+    project_ty *pp = sub_context_project_get(scp);
     if (!pp)
     {
-	sub_context_error_set(scp, i18n("not valid in current context"));
-	result = 0;
-	goto done;
+	scp->error_set(i18n("not valid in current context"));
+        trace(("}\n"));
+        return result;
     }
 
-    result = str_to_wstr(pp->history_path_get());
+    result = wstring(pp->history_path_get());
 
-    done:
-    trace(("return %8.8lX;\n", (long)result));
+    trace(("return %8.8lX;\n", (long)result.get_ref()));
     trace(("}\n"));
     return result;
 }
